// Copyright 2006-2010, by the California Institute of Technology.
// ALL RIGHTS RESERVED. United States Government Sponsorship acknowledged.
// Any commercial use must be negotiated with the Office of Technology Transfer
// at the California Institute of Technology.
//
// This software is subject to U. S. export control laws and regulations
// (22 C.F.R. 120-130 and 15 C.F.R. 730-774). To the extent that the software
// is subject to U.S. export control laws and regulations, the recipient has
// the responsibility to obtain export licenses or other export authority as
// may be required before exporting such information to foreign countries or
// providing access to foreign nationals.
//
// $Id: Scalar.java 8263 2010-12-08 22:03:38Z mcayanan $
//

package gov.nasa.pds.tools.label;

import gov.nasa.pds.tools.constants.Constants.DictionaryType;

/**
 * This class represents a Scalar which can be assigned to an attribute or be a
 * part of a Set or Sequence.
 * 
 * @author pramirez
 * @author jagander
 * @version $Revision: 8263 $
 * 
 */
public abstract class Scalar implements Value {

    private String value;

    /**
     * Constructs a Scalar
     * 
     * @param value
     */
    protected Scalar(String value) {
        this.value = value;
    }

    /**
     * Retrieves the value
     * 
     * @return the value
     */
    public String getValue() {
        return this.value;
    }

    @Override
    public String toString() {
        return this.value;
    }

    public abstract boolean isSupportedPDSType(DictionaryType type);

    public boolean equals(Object object) {
        if (this == object) {
            return true;
        }
        if (!(object instanceof Scalar)) {
            return false;
        }
        Scalar that = (Scalar) object;
        return this.value.equals(that.getValue());
    }

    public int hashcode() {
        return this.value.hashCode();
    }
}
